@@ -22,11 +22,20 @@ export function getFieldsWithStats(dataFrames: DataFrame[]): FieldWithStats[] {
     const fields = (logsFrame?.extraFields ?? [])
       .filter((field) => !field?.config?.custom?.hidden)
       .map((field) => {
-        cardinality.set(field.name, field.values.filter((value) => value !== null && value !== undefined).length);
+        const count = field.values.filter((value) => value !== null && value !== undefined).length;
+        cardinality.set(field.name, (cardinality.get(field.name) ?? 0) + count);
         return field.name;
       });
 
-    return [...labels, ...fields];
+    // Include severity field (level/detected_level) - it's excluded from extraFields but should be selectable
+    const severityFieldNames: string[] = [];
+    if (logsFrame?.severityField && !logsFrame.severityField.config?.custom?.hidden) {
+      const count = logsFrame.severityField.values.filter((value) => value !== null && value !== undefined).length;
+      cardinality.set(logsFrame.severityField.name, (cardinality.get(logsFrame.severityField.name) ?? 0) + count);
+      severityFieldNames.push(logsFrame.severityField.name);
+    }
+
+    return [...labels, ...fields, ...severityFieldNames];
   });
 
   const labels = [...new Set(allFields)];
